require 'spec_helper'
require 'json'

describe 'DataApi' do

  let(:instance) { FCP::DataApi.new }

  specify { expect(instance).to be_instance_of(FCP::DataApi) }

  # tests for #get_lookup
  # Geo Lookup
  #
  # Takes a valid latitude, longitude and radius (in km) and returns all matching postcodes within that area. This operation does not return full addresses (which must be queried for separately). 
  # 
  # Test positions are based upon data here: 
  # 
  # https://github.com/firstclasspostcodes/firstclasspostcodes-mock/blob/master/DATA.md
  #
  # @param latitude The latitude for the query 
  # @param longitude The latitude for the query 
  # @param [Hash] opts the optional parameters
  # @option opts [Float] :radius The radius, in kilometers. 
  # @return [Array<Point>]
  describe '#get_lookup' do
    [%w(51.469275	-0.266110), %w(51.469284	-0.266096)].each do |position|
      specify { expect(instance.get_lookup(*position)).to all(be_instance_of(FCP::Point)) }
    end

    describe 'when an unsupported position' do
      specify { expect(instance.get_lookup(51.90026, 2.62673)).to be_nil }
    end
  end

  # tests for #get_postcode
  # Postcode Lookup
  #
  # Retrieves street numbers, address and location information for a specific postcode provided in the search query parameter. 
  # 
  # Test postcodes are based upon data here: 
  # 
  # https://github.com/firstclasspostcodes/firstclasspostcodes-mock/blob/master/DATA.md
  #
  # @param search The postcode to retrieve address information for. 
  # @param [Hash] opts the optional parameters
  # @return [Address]
  describe '#get_postcode' do
    ['TW9 1XW', 'tw91xw', 'tw9 1xw'].each do |postcode|
      describe "Response when '?search=#{postcode}'" do
        specify { expect(instance.get_postcode(postcode)).to be_instance_of(FCP::Address) }
      end
    end

    describe 'with an unsupported postcode' do
      specify { expect(instance.get_postcode('XX43 FGH')).to be_nil }
    end
  end

  # tests for #get_typeahead
  # Typeahead Search
  #
  # Performs a typeahead search for an address, allowing the user to enter their address naturally.  
  #
  # @param search The typeahead search query to return matching results for. 
  # @param [Hash] opts the optional parameters
  # @return [Array<Typeahead>]
  describe '#get_typeahead' do
    ['fl', 'fla', 'flat', '1', '13', '25'].each do |search|
      describe "Response when '?search=#{search}'" do
        specify { expect(instance.get_typeahead(search)).to all(be_instance_of(FCP::Typeahead)) }
      end
    end
  end

end
